summaryrefslogtreecommitdiffstats
path: root/tools/post_process_props.py
diff options
context:
space:
mode:
authorMichael Bestas <mikeioannina@gmail.com>2015-02-19 14:29:21 +0200
committerAdnan Begovic <adnan@cyngn.com>2015-10-06 18:43:37 -0700
commit0fdfb4649631bdc5d86bfe821b89c4b7a06bffd0 (patch)
treef0953f50d6c2142eac340505f267804ac5549987 /tools/post_process_props.py
parent37e92c2fe7310ceae1a0d65e44c2309adb5789bd (diff)
downloadbuild-0fdfb4649631bdc5d86bfe821b89c4b7a06bffd0.zip
build-0fdfb4649631bdc5d86bfe821b89c4b7a06bffd0.tar.gz
build-0fdfb4649631bdc5d86bfe821b89c4b7a06bffd0.tar.bz2
Don't enable ADB by default on userdebug builds
Change-Id: I33ae5c6f2787017a62e679aa0c28d4b909d45935
Diffstat (limited to 'tools/post_process_props.py')
-rwxr-xr-xtools/post_process_props.py5
1 files changed, 2 insertions, 3 deletions
diff --git a/tools/post_process_props.py b/tools/post_process_props.py
index cbbf1f1..ec1aace 100755
--- a/tools/post_process_props.py
+++ b/tools/post_process_props.py
@@ -40,9 +40,8 @@ def mangle_build_prop(prop, overrides):
# Put the modifications that you need to make into the /default.prop into this
# function. The prop object has get(name) and put(name,value) methods.
def mangle_default_prop(prop):
- # If ro.debuggable is 1, then enable adb on USB by default
- # (this is for userdebug builds)
- if prop.get("ro.debuggable") == "1":
+ # If ro.build.type is eng, then enable adb on USB by default
+ if prop.get("ro.build.type") == "eng":
val = prop.get("persist.sys.usb.config")
if val == "":
val = "adb"